# vs-masktools

vs-masktools aims to provide tools and functions to manage, create, and manipulate masks in VapourSynth.

For support you can check out the [JET Discord server](https://discord.gg/XTpc6Fa9eB). <br><br>

# Installation

vs-masktools is available on PyPi and can be installed with this simple command:

```
pip install vsmasktools
```

# Dependencies

The only hard dependencies are vstools and an installation of VapourSynth R59 or higher. However, for full functionality, you should make sure to also install:
- [TCanny](https://github.com/HomeOfVapourSynthEvolution/VapourSynth-TCanny)
- [TEdgeMask](https://github.com/dubhater/vapoursynth-tedgemask)
- [AWarpSharp2](https://github.com/dubhater/vapoursynth-awarpsharp2)
- [AWarpSharp2SF](https://github.com/IFeelBloated/warpsharp)
- [vszip](https://github.com/dnjulek/vapoursynth-zip)
